# Amiga Library Services - CD Administration Makefile
#
# This Makefile goes in the root directory of the BBS tree, and
# is responsible for doing such things as:
#
# (1)	Build an accumulated "Contents" file for all material in this tree.
#
# (2)	Build a "Quick Reference" file for all material in this tree.
#

all:	Contents QuickRef FILES.BBS

# Generate a summary file called "Contents".

Contents:
	echo "This file is generated automatically from the product info files" >Contents
	echo "included in this tree." >>Contents
	echo "" >>Contents
	find . \( -name Product-Info -o -name '*.pi' \) -print \
	  | sort -f \
	  | sed "s:^./::" \
	  | pitool -f - -b -F "==========\n\n%N    %V    %S\n\n%d\n\nAuthor: %a\nPath: %P\n\n" - >>Contents

# Generate a quick reference file, which contains the name of the product,
# the version number, and the short description; one product per line.

QuickRef:
	echo "This file is generated automatically from the product info files" >QuickRef
	echo "included in this tree.  See the 'Contents' file for additional" >>QuickRef
	echo "information about each item." >>QuickRef
	echo "" >>QuickRef
	pitool -b -F "%-16.16N  %8.8V   %-S\n" -f - . | sort -f | uniq >>QuickRef

# Build default FILES.BBS files in all the directories that have 
# product info files.  First we find and delete existing files, since
# the default is to append to the file.  Note we have to sort the files
# after creating them.

FILES.BBS:
	find . -name files.bbs -print -exec rm {} \;
	pitool -b .
	for i in `find . -name files.bbs -print`; \
	do \
		sort -f <$$i >/tmp/files.bbs; \
		cp /tmp/files.bbs $$i; \
	done

clean:
	rm -f *! *~

# Remove all automatically generated files.

clobber: clean
	rm -f Contents QuickRef
	find . -name files.bbs -print -exec rm {} \;
